
# Slot: tag


a tag associated with an extension

URI: [linkml:extension_tag](https://w3id.org/linkml/extension_tag)


## Domain and Range

extension &#8594;  <sub>1..1</sub> uriorcurie

## Parents


## Children


## Used by

 * annotation
 * extension
